==> ui-framework-4.13.4-sources.jar: io/intino/alexandria/ui/displays/templates/AbstractMultipleExamplesMold.java <==
package io.intino.alexandria.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractMultipleExamplesMold<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public Content content;
	public MultipleExamplesMold.Content. _8_2_0904849092 _8_2_0904849092;
	public MultipleExamplesMold.Content._8_2_0904849092. _9_3_0308355687 _9_3_0308355687;
	public MultipleExamplesMold.Content._8_2_0904849092. _10_3_1218086142 _10_3_1218086142;
	public MultipleExamplesMold.Content._8_2_0904849092._10_3_1218086142. Multiple1 multiple1;
	public MultipleExamplesMold.Content._8_2_0904849092._10_3_1218086142. _12_4_01337308662 _12_4_01337308662;
	public MultipleExamplesMold.Content._8_2_0904849092._10_3_1218086142._12_4_01337308662. Multiple1Code multiple1Code;
	public MultipleExamplesMold.Content. Multiple2Block multiple2Block;
	public MultipleExamplesMold.Content.Multiple2Block. _19_3_0438250040 _19_3_0438250040;
	public MultipleExamplesMold.Content.Multiple2Block. Multiple2Content multiple2Content;
	public MultipleExamplesMold.Content.Multiple2Block.Multiple2Content. Multiple2 multiple2;
	public MultipleExamplesMold.Content.Multiple2Block.Multiple2Content. _22_4_11910869069 _22_4_11910869069;
	public MultipleExamplesMold.Content.Multiple2Block.Multiple2Content._22_4_11910869069. Multiple2Code multiple2Code;

    public AbstractMultipleExamplesMold(B box) {
        super(box);
        id("multipleExamplesMold");
    }

    @Override
	public void init() {
		super.init();
		if (content == null) content = register(new Content(box()).<Content>id("a1791632588").owner(AbstractMultipleExamplesMold.this));
		if (content != null) _8_2_0904849092 = content._8_2_0904849092;
		if (_8_2_0904849092 != null) _9_3_0308355687 = content._8_2_0904849092._9_3_0308355687;
		if (_8_2_0904849092 != null) _10_3_1218086142 = content._8_2_0904849092._10_3_1218086142;
		if (_10_3_1218086142 != null) multiple1 = content._8_2_0904849092._10_3_1218086142.multiple1;
		if (_10_3_1218086142 != null) _12_4_01337308662 = content._8_2_0904849092._10_3_1218086142._12_4_01337308662;
		if (_12_4_01337308662 != null) multiple1Code = content._8_2_0904849092._10_3_1218086142._12_4_01337308662.multiple1Code;
		if (content != null) multiple2Block = content.multiple2Block;
		if (multiple2Block != null) _19_3_0438250040 = content.multiple2Block._19_3_0438250040;
		if (multiple2Block != null) multiple2Content = content.multiple2Block.multiple2Content;
		if (multiple2Content != null) multiple2 = content.multiple2Block.multiple2Content.multiple2;
		if (multiple2Content != null) _22_4_11910869069 = content.multiple2Block.multiple2Content._22_4_11910869069;
		if (_22_4_11910869069 != null) multiple2Code = content.multiple2Block.multiple2Content._22_4_11910869069.multiple2Code;
	}

	public class Content extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public MultipleExamplesMold.Content. _8_2_0904849092 _8_2_0904849092;
		public MultipleExamplesMold.Content. Multiple2Block multiple2Block;

		public Content(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_8_2_0904849092 == null) _8_2_0904849092 = register(new _8_2_0904849092(box()).<_8_2_0904849092>id("a_400153351").owner(AbstractMultipleExamplesMold.this));
			if (multiple2Block == null) multiple2Block = register(new Multiple2Block(box()).<Multiple2Block>id("a46241118").owner(AbstractMultipleExamplesMold.this));
		}

		public class _8_2_0904849092 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public MultipleExamplesMold.Content._8_2_0904849092. _9_3_0308355687 _9_3_0308355687;
			public MultipleExamplesMold.Content._8_2_0904849092. _10_3_1218086142 _10_3_1218086142;

			public _8_2_0904849092(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_9_3_0308355687 == null) _9_3_0308355687 = register(new _9_3_0308355687(box()).<_9_3_0308355687>id("a_518700325").owner(AbstractMultipleExamplesMold.this));
				if (_10_3_1218086142 == null) _10_3_1218086142 = register(new _10_3_1218086142(box()).<_10_3_1218086142>id("a1709711481").owner(AbstractMultipleExamplesMold.this));
			}

			public class _9_3_0308355687 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _9_3_0308355687(B box) {
					super(box);
					_value("No facets");
				}

				@Override
				public void init() {
					super.init();
				}
			}

			public class _10_3_1218086142 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public MultipleExamplesMold.Content._8_2_0904849092._10_3_1218086142. Multiple1 multiple1;
				public MultipleExamplesMold.Content._8_2_0904849092._10_3_1218086142. _12_4_01337308662 _12_4_01337308662;

				public _10_3_1218086142(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (multiple1 == null) multiple1 = register(new Multiple1(box()).<Multiple1>id("a_1558470940").owner(AbstractMultipleExamplesMold.this));
					if (_12_4_01337308662 == null) _12_4_01337308662 = register(new _12_4_01337308662(box()).<_12_4_01337308662>id("a_1815087418").owner(AbstractMultipleExamplesMold.this));
				}

				public class Multiple1 extends io.intino.alexandria.ui.displays.components.Multiple<B,Text, java.lang.String> implements io.intino.alexandria.ui.displays.components.multiple.NonCollapsable<B,Text, java.lang.String> {

					public Multiple1(B box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public Text add(java.lang.String value) {
						Text child = new Text(box());
						child.id(java.util.UUID.randomUUID().toString());
						add(child, "multiple1");
						child.value(value);
					    notifyAdd(child, value);
						return child;
					}
					@Override
					public void remove(Text child) {
						removeChild(child, "multiple1");
					}
					public void clear() {
					    super.clear("multiple1");
					}
				}

				public class _12_4_01337308662 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
					public MultipleExamplesMold.Content._8_2_0904849092._10_3_1218086142._12_4_01337308662. Multiple1Code multiple1Code;

					public _12_4_01337308662(B box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
						if (multiple1Code == null) multiple1Code = register(new Multiple1Code(box()).<Multiple1Code>id("a1475925300").owner(AbstractMultipleExamplesMold.this));
					}

					public class Multiple1Code extends io.intino.alexandria.ui.displays.components.Multiple<B,Text, java.lang.String> implements io.intino.alexandria.ui.displays.components.multiple.NonCollapsable<B,Text, java.lang.String> {

						public Multiple1Code(B box) {
							super(box);
						}

						@Override
						public void init() {
							super.init();
						}

						@Override
						public Text add(java.lang.String value) {
							Text child = new Text(box());
							child.id(java.util.UUID.randomUUID().toString());
							add(child, "multiple1Code");
							child.value(value);
						    notifyAdd(child, value);
							return child;
						}
						@Override
						public void remove(Text child) {
							removeChild(child, "multiple1Code");
						}
						public void clear() {
						    super.clear("multiple1Code");
						}
					}
				}
			}
		}

		public class Multiple2Block extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public MultipleExamplesMold.Content.Multiple2Block. _19_3_0438250040 _19_3_0438250040;
			public MultipleExamplesMold.Content.Multiple2Block. Multiple2Content multiple2Content;

			public Multiple2Block(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_19_3_0438250040 == null) _19_3_0438250040 = register(new _19_3_0438250040(box()).<_19_3_0438250040>id("a_1020127059").owner(AbstractMultipleExamplesMold.this));
				if (multiple2Content == null) multiple2Content = register(new Multiple2Content(box()).<Multiple2Content>id("a_172385608").owner(AbstractMultipleExamplesMold.this));
			}

			public class _19_3_0438250040 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _19_3_0438250040(B box) {
					super(box);
					_value("No facets with collapsed");
				}

				@Override
				public void init() {
					super.init();
				}
			}

			public class Multiple2Content extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public MultipleExamplesMold.Content.Multiple2Block.Multiple2Content. Multiple2 multiple2;
				public MultipleExamplesMold.Content.Multiple2Block.Multiple2Content. _22_4_11910869069 _22_4_11910869069;

				public Multiple2Content(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (multiple2 == null) multiple2 = register(new Multiple2((UiFrameworkBox)box()).<Multiple2>id("a_641815717").owner(AbstractMultipleExamplesMold.this));
					if (_22_4_11910869069 == null) _22_4_11910869069 = register(new _22_4_11910869069(box()).<_22_4_11910869069>id("a_1156414114").owner(AbstractMultipleExamplesMold.this));
				}

				public class Multiple2 extends io.intino.alexandria.ui.displays.components.Multiple<UiFrameworkBox,Multiple2Template, java.lang.Void> implements io.intino.alexandria.ui.displays.components.multiple.Collapsable<UiFrameworkBox,Multiple2Template, java.lang.Void> {

					public Multiple2(UiFrameworkBox box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public Multiple2Template add(java.lang.Void value, String label, String description) {
						Multiple2Template child = new Multiple2Template(box());
						child.id(java.util.UUID.randomUUID().toString());
					    child.properties().put("label", label);
					    child.properties().put("description", description);
						add(child, "multiple2");
					    notifyAdd(child);
						return child;
					}
					@Override
					public void remove(Multiple2Template child) {
						removeChild(child, "multiple2");
					}
					public void clear() {
					    super.clear("multiple2");
					}
					@Override
					protected Multiple2Template add(java.lang.Void value) {
					    return add(value, null, null);
					}
				}

				public class _22_4_11910869069 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
					public MultipleExamplesMold.Content.Multiple2Block.Multiple2Content._22_4_11910869069. Multiple2Code multiple2Code;

					public _22_4_11910869069(B box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
						if (multiple2Code == null) multiple2Code = register(new Multiple2Code(box()).<Multiple2Code>id("a479776468").owner(AbstractMultipleExamplesMold.this));
					}

					public class Multiple2Code extends io.intino.alexandria.ui.displays.components.Multiple<B,Text, java.lang.String> implements io.intino.alexandria.ui.displays.components.multiple.NonCollapsable<B,Text, java.lang.String> {

						public Multiple2Code(B box) {
							super(box);
						}

						@Override
						public void init() {
							super.init();
						}

						@Override
						public Text add(java.lang.String value) {
							Text child = new Text(box());
							child.id(java.util.UUID.randomUUID().toString());
							add(child, "multiple2Code");
							child.value(value);
						    notifyAdd(child, value);
							return child;
						}
						@Override
						public void remove(Text child) {
							removeChild(child, "multiple2Code");
						}
						public void clear() {
						    super.clear("multiple2Code");
						}
					}
				}
			}
		}
	}
}

==> ui-framework-4.14.8-sources.jar: io/intino/alexandria/ui/displays/templates/AbstractMultipleExamplesMold.java <==
package io.intino.alexandria.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractMultipleExamplesMold<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public Content content;
	public MultipleExamplesMold.Content. _8_2_0904849092 _8_2_0904849092;
	public MultipleExamplesMold.Content._8_2_0904849092. _9_3_0308355687 _9_3_0308355687;
	public MultipleExamplesMold.Content._8_2_0904849092. _10_3_1218086142 _10_3_1218086142;
	public MultipleExamplesMold.Content._8_2_0904849092._10_3_1218086142. Multiple1 multiple1;
	public MultipleExamplesMold.Content._8_2_0904849092._10_3_1218086142. _12_4_01337308662 _12_4_01337308662;
	public MultipleExamplesMold.Content._8_2_0904849092._10_3_1218086142._12_4_01337308662. Multiple1Code multiple1Code;
	public MultipleExamplesMold.Content. Multiple2Block multiple2Block;
	public MultipleExamplesMold.Content.Multiple2Block. _19_3_0438250040 _19_3_0438250040;
	public MultipleExamplesMold.Content.Multiple2Block. Multiple2Content multiple2Content;
	public MultipleExamplesMold.Content.Multiple2Block.Multiple2Content. Multiple2 multiple2;
	public MultipleExamplesMold.Content.Multiple2Block.Multiple2Content. _22_4_11802457069 _22_4_11802457069;
	public MultipleExamplesMold.Content.Multiple2Block.Multiple2Content._22_4_11802457069. Multiple2Code multiple2Code;
	public _30_1_01589236872 _30_1_01589236872;
	public MultipleExamplesMold._30_1_01589236872. _31_2_01888664175 _31_2_01888664175;
	public MultipleExamplesMold._30_1_01589236872._31_2_01888664175. _32_3_1817355492 _32_3_1817355492;
	public MultipleExamplesMold._30_1_01589236872._31_2_01888664175. _33_3_0184392530 _33_3_0184392530;
	public MultipleExamplesMold._30_1_01589236872._31_2_01888664175._33_3_0184392530. Multiple3 multiple3;
	public MultipleExamplesMold._30_1_01589236872._31_2_01888664175._33_3_0184392530. _35_4_0673758 _35_4_0673758;
	public MultipleExamplesMold._30_1_01589236872._31_2_01888664175._33_3_0184392530._35_4_0673758. Multiple3Code multiple3Code;

    public AbstractMultipleExamplesMold(B box) {
        super(box);
        id("multipleExamplesMold");
    }

    @Override
	public void init() {
		super.init();
		if (content == null) content = register(new Content(box()).<Content>id("a1791632588").owner(AbstractMultipleExamplesMold.this));
		if (content != null) _8_2_0904849092 = content._8_2_0904849092;
		if (_8_2_0904849092 != null) _9_3_0308355687 = content._8_2_0904849092._9_3_0308355687;
		if (_8_2_0904849092 != null) _10_3_1218086142 = content._8_2_0904849092._10_3_1218086142;
		if (_10_3_1218086142 != null) multiple1 = content._8_2_0904849092._10_3_1218086142.multiple1;
		if (_10_3_1218086142 != null) _12_4_01337308662 = content._8_2_0904849092._10_3_1218086142._12_4_01337308662;
		if (_12_4_01337308662 != null) multiple1Code = content._8_2_0904849092._10_3_1218086142._12_4_01337308662.multiple1Code;
		if (content != null) multiple2Block = content.multiple2Block;
		if (multiple2Block != null) _19_3_0438250040 = content.multiple2Block._19_3_0438250040;
		if (multiple2Block != null) multiple2Content = content.multiple2Block.multiple2Content;
		if (multiple2Content != null) multiple2 = content.multiple2Block.multiple2Content.multiple2;
		if (multiple2Content != null) _22_4_11802457069 = content.multiple2Block.multiple2Content._22_4_11802457069;
		if (_22_4_11802457069 != null) multiple2Code = content.multiple2Block.multiple2Content._22_4_11802457069.multiple2Code;
		if (_30_1_01589236872 == null) _30_1_01589236872 = register(new _30_1_01589236872(box()).<_30_1_01589236872>id("a884105461").owner(AbstractMultipleExamplesMold.this));
		if (_30_1_01589236872 != null) _31_2_01888664175 = _30_1_01589236872._31_2_01888664175;
		if (_31_2_01888664175 != null) _32_3_1817355492 = _30_1_01589236872._31_2_01888664175._32_3_1817355492;
		if (_31_2_01888664175 != null) _33_3_0184392530 = _30_1_01589236872._31_2_01888664175._33_3_0184392530;
		if (_33_3_0184392530 != null) multiple3 = _30_1_01589236872._31_2_01888664175._33_3_0184392530.multiple3;
		if (_33_3_0184392530 != null) _35_4_0673758 = _30_1_01589236872._31_2_01888664175._33_3_0184392530._35_4_0673758;
		if (_35_4_0673758 != null) multiple3Code = _30_1_01589236872._31_2_01888664175._33_3_0184392530._35_4_0673758.multiple3Code;
	}

	public class Content extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public MultipleExamplesMold.Content. _8_2_0904849092 _8_2_0904849092;
		public MultipleExamplesMold.Content. Multiple2Block multiple2Block;

		public Content(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_8_2_0904849092 == null) _8_2_0904849092 = register(new _8_2_0904849092(box()).<_8_2_0904849092>id("a_400153351").owner(AbstractMultipleExamplesMold.this));
			if (multiple2Block == null) multiple2Block = register(new Multiple2Block(box()).<Multiple2Block>id("a46241118").owner(AbstractMultipleExamplesMold.this));
		}

		public class _8_2_0904849092 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public MultipleExamplesMold.Content._8_2_0904849092. _9_3_0308355687 _9_3_0308355687;
			public MultipleExamplesMold.Content._8_2_0904849092. _10_3_1218086142 _10_3_1218086142;

			public _8_2_0904849092(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_9_3_0308355687 == null) _9_3_0308355687 = register(new _9_3_0308355687(box()).<_9_3_0308355687>id("a_518700325").owner(AbstractMultipleExamplesMold.this));
				if (_10_3_1218086142 == null) _10_3_1218086142 = register(new _10_3_1218086142(box()).<_10_3_1218086142>id("a1709711481").owner(AbstractMultipleExamplesMold.this));
			}

			public class _9_3_0308355687 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _9_3_0308355687(B box) {
					super(box);
					_value("No facets");
				}

				@Override
				public void init() {
					super.init();
				}
			}

			public class _10_3_1218086142 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public MultipleExamplesMold.Content._8_2_0904849092._10_3_1218086142. Multiple1 multiple1;
				public MultipleExamplesMold.Content._8_2_0904849092._10_3_1218086142. _12_4_01337308662 _12_4_01337308662;

				public _10_3_1218086142(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (multiple1 == null) multiple1 = register(new Multiple1(box()).<Multiple1>id("a_1558470940").owner(AbstractMultipleExamplesMold.this));
					if (_12_4_01337308662 == null) _12_4_01337308662 = register(new _12_4_01337308662(box()).<_12_4_01337308662>id("a_1815087418").owner(AbstractMultipleExamplesMold.this));
				}

				public class Multiple1 extends io.intino.alexandria.ui.displays.components.Multiple<B,Text, java.lang.String> implements io.intino.alexandria.ui.displays.components.multiple.NonCollapsable<B,Text, java.lang.String> {

					public Multiple1(B box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public Text add(java.lang.String value) {
						Text child = new Text(box());
						child.id(java.util.UUID.randomUUID().toString());
						add(child, "multiple1");
						child.value(value);
					    notifyAdd(child, value);
						return child;
					}
					@Override
					public void remove(Text child) {
						removeChild(child, "multiple1");
					}
					public void clear() {
					    super.clear("multiple1");
					}
				}

				public class _12_4_01337308662 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
					public MultipleExamplesMold.Content._8_2_0904849092._10_3_1218086142._12_4_01337308662. Multiple1Code multiple1Code;

					public _12_4_01337308662(B box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
						if (multiple1Code == null) multiple1Code = register(new Multiple1Code(box()).<Multiple1Code>id("a1475925300").owner(AbstractMultipleExamplesMold.this));
					}

					public class Multiple1Code extends io.intino.alexandria.ui.displays.components.Multiple<B,Text, java.lang.String> implements io.intino.alexandria.ui.displays.components.multiple.NonCollapsable<B,Text, java.lang.String> {

						public Multiple1Code(B box) {
							super(box);
						}

						@Override
						public void init() {
							super.init();
						}

						@Override
						public Text add(java.lang.String value) {
							Text child = new Text(box());
							child.id(java.util.UUID.randomUUID().toString());
							add(child, "multiple1Code");
							child.value(value);
						    notifyAdd(child, value);
							return child;
						}
						@Override
						public void remove(Text child) {
							removeChild(child, "multiple1Code");
						}
						public void clear() {
						    super.clear("multiple1Code");
						}
					}
				}
			}
		}

		public class Multiple2Block extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public MultipleExamplesMold.Content.Multiple2Block. _19_3_0438250040 _19_3_0438250040;
			public MultipleExamplesMold.Content.Multiple2Block. Multiple2Content multiple2Content;

			public Multiple2Block(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_19_3_0438250040 == null) _19_3_0438250040 = register(new _19_3_0438250040(box()).<_19_3_0438250040>id("a_1020127059").owner(AbstractMultipleExamplesMold.this));
				if (multiple2Content == null) multiple2Content = register(new Multiple2Content(box()).<Multiple2Content>id("a_172385608").owner(AbstractMultipleExamplesMold.this));
			}

			public class _19_3_0438250040 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _19_3_0438250040(B box) {
					super(box);
					_value("No facets with collapsed");
				}

				@Override
				public void init() {
					super.init();
				}
			}

			public class Multiple2Content extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public MultipleExamplesMold.Content.Multiple2Block.Multiple2Content. Multiple2 multiple2;
				public MultipleExamplesMold.Content.Multiple2Block.Multiple2Content. _22_4_11802457069 _22_4_11802457069;

				public Multiple2Content(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (multiple2 == null) multiple2 = register(new Multiple2((UiFrameworkBox)box()).<Multiple2>id("a_641815717").owner(AbstractMultipleExamplesMold.this));
					if (_22_4_11802457069 == null) _22_4_11802457069 = register(new _22_4_11802457069(box()).<_22_4_11802457069>id("a567737669").owner(AbstractMultipleExamplesMold.this));
				}

				public class Multiple2 extends io.intino.alexandria.ui.displays.components.Multiple<UiFrameworkBox,Multiple2Template, java.lang.Void> implements io.intino.alexandria.ui.displays.components.multiple.Collapsable<UiFrameworkBox,Multiple2Template, java.lang.Void> {

					public Multiple2(UiFrameworkBox box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public Multiple2Template add(java.lang.Void value, String label, String description) {
						Multiple2Template child = new Multiple2Template(box());
						child.id(java.util.UUID.randomUUID().toString());
					    child.properties().put("label", label);
					    child.properties().put("description", description);
						add(child, "multiple2");
					    notifyAdd(child);
						return child;
					}
					@Override
					public void remove(Multiple2Template child) {
						removeChild(child, "multiple2");
					}
					public void clear() {
					    super.clear("multiple2");
					}
					@Override
					protected Multiple2Template add(java.lang.Void value) {
					    return add(value, null, null);
					}
				}

				public class _22_4_11802457069 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
					public MultipleExamplesMold.Content.Multiple2Block.Multiple2Content._22_4_11802457069. Multiple2Code multiple2Code;

					public _22_4_11802457069(B box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
						if (multiple2Code == null) multiple2Code = register(new Multiple2Code(box()).<Multiple2Code>id("a479776468").owner(AbstractMultipleExamplesMold.this));
					}

					public class Multiple2Code extends io.intino.alexandria.ui.displays.components.Multiple<B,Text, java.lang.String> implements io.intino.alexandria.ui.displays.components.multiple.NonCollapsable<B,Text, java.lang.String> {

						public Multiple2Code(B box) {
							super(box);
						}

						@Override
						public void init() {
							super.init();
						}

						@Override
						public Text add(java.lang.String value) {
							Text child = new Text(box());
							child.id(java.util.UUID.randomUUID().toString());
							add(child, "multiple2Code");
							child.value(value);
						    notifyAdd(child, value);
							return child;
						}
						@Override
						public void remove(Text child) {
							removeChild(child, "multiple2Code");
						}
						public void clear() {
						    super.clear("multiple2Code");
						}
					}
				}
			}
		}
	}

	public class _30_1_01589236872 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public MultipleExamplesMold._30_1_01589236872. _31_2_01888664175 _31_2_01888664175;

		public _30_1_01589236872(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_31_2_01888664175 == null) _31_2_01888664175 = register(new _31_2_01888664175(box()).<_31_2_01888664175>id("a_1193515422").owner(AbstractMultipleExamplesMold.this));
		}

		public class _31_2_01888664175 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public MultipleExamplesMold._30_1_01589236872._31_2_01888664175. _32_3_1817355492 _32_3_1817355492;
			public MultipleExamplesMold._30_1_01589236872._31_2_01888664175. _33_3_0184392530 _33_3_0184392530;

			public _31_2_01888664175(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_32_3_1817355492 == null) _32_3_1817355492 = register(new _32_3_1817355492(box()).<_32_3_1817355492>id("a224265843").owner(AbstractMultipleExamplesMold.this));
				if (_33_3_0184392530 == null) _33_3_0184392530 = register(new _33_3_0184392530(box()).<_33_3_0184392530>id("a633332270").owner(AbstractMultipleExamplesMold.this));
			}

			public class _32_3_1817355492 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _32_3_1817355492(B box) {
					super(box);
					_value("No facets with Image");
				}

				@Override
				public void init() {
					super.init();
				}
			}

			public class _33_3_0184392530 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public MultipleExamplesMold._30_1_01589236872._31_2_01888664175._33_3_0184392530. Multiple3 multiple3;
				public MultipleExamplesMold._30_1_01589236872._31_2_01888664175._33_3_0184392530. _35_4_0673758 _35_4_0673758;

				public _33_3_0184392530(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (multiple3 == null) multiple3 = register(new Multiple3(box()).<Multiple3>id("a845170087").owner(AbstractMultipleExamplesMold.this));
					if (_35_4_0673758 == null) _35_4_0673758 = register(new _35_4_0673758(box()).<_35_4_0673758>id("a2077176115").owner(AbstractMultipleExamplesMold.this));
				}

				public class Multiple3 extends io.intino.alexandria.ui.displays.components.MultipleImage<B, Multiple3.ImageEditable, io.intino.alexandria.ui.File> implements io.intino.alexandria.ui.displays.components.multiple.NonCollapsable<B, Multiple3.ImageEditable, io.intino.alexandria.ui.File> {

					public Multiple3(B box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
					}
					public void onAdd(io.intino.alexandria.ui.displays.events.editable.AddItemListener listener) {
						super.addItemListener(listener);
					}
					public void onChange(io.intino.alexandria.ui.displays.events.editable.ChangeItemListener listener) {
						super.changeItemListener(listener);
					}
					public void onRemove(io.intino.alexandria.ui.displays.events.editable.RemoveItemListener listener) {
						super.removeItemListener(listener);
					}
					public class ImageEditable extends io.intino.alexandria.ui.displays.components.ImageEditable {
					    public ImageEditable(B box) {
					        super(box);
					    }
					}
					@Override
					public ImageEditable add(io.intino.alexandria.ui.File value) {
						ImageEditable child = new ImageEditable(box());
						child.id(java.util.UUID.randomUUID().toString());
						add(child, "multiple3");
						child.value(value);
					    notifyAdd(child, value);
						return child;
					}
					@Override
					public void remove(ImageEditable child) {
						removeChild(child, "multiple3");
					}
					public void clear() {
					    super.clear("multiple3");
					}
				}

				public class _35_4_0673758 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
					public MultipleExamplesMold._30_1_01589236872._31_2_01888664175._33_3_0184392530._35_4_0673758. Multiple3Code multiple3Code;

					public _35_4_0673758(B box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
						if (multiple3Code == null) multiple3Code = register(new Multiple3Code(box()).<Multiple3Code>id("a_751410569").owner(AbstractMultipleExamplesMold.this));
					}

					public class Multiple3Code extends io.intino.alexandria.ui.displays.components.Multiple<B,Text, java.lang.String> implements io.intino.alexandria.ui.displays.components.multiple.NonCollapsable<B,Text, java.lang.String> {

						public Multiple3Code(B box) {
							super(box);
						}

						@Override
						public void init() {
							super.init();
						}

						@Override
						public Text add(java.lang.String value) {
							Text child = new Text(box());
							child.id(java.util.UUID.randomUUID().toString());
							add(child, "multiple3Code");
							child.value(value);
						    notifyAdd(child, value);
							return child;
						}
						@Override
						public void remove(Text child) {
							removeChild(child, "multiple3Code");
						}
						public void clear() {
						    super.clear("multiple3Code");
						}
					}
				}
			}
		}
	}
}
